ALTER TABLE Token
    DROP FOREIGN KEY FKToken1;

ALTER TABLE Param
    DROP FOREIGN KEY FKParam1;

ALTER TABLE Feature
    DROP FOREIGN KEY FKFeature1;

ALTER TABLE WidgetType
    DROP FOREIGN KEY FKWidgetType1;

ALTER TABLE WidgetDefault
    DROP FOREIGN KEY FKWidgetDefault1;

ALTER TABLE SharedData
    DROP FOREIGN KEY FKSharedData1;

ALTER TABLE Preference
    DROP FOREIGN KEY FKPreference1;

ALTER TABLE Participant
    DROP FOREIGN KEY FKParticipant1;

ALTER TABLE PreferenceDefault
    DROP FOREIGN KEY FKPreferenceDefault1;

ALTER TABLE WidgetInstance
    DROP FOREIGN KEY FKWidgetInstance1;

ALTER TABLE StartFile
    DROP FOREIGN KEY FKStartFile1;

ALTER TABLE Description
    DROP FOREIGN KEY FKDescription1;

ALTER TABLE AccessRequest
    DROP FOREIGN KEY FKAccessRequest1;

ALTER TABLE Name
    DROP FOREIGN KEY FKName1;

ALTER TABLE License
    DROP FOREIGN KEY FKLicense1;

ALTER TABLE WidgetIcon
    DROP FOREIGN KEY FKWidgetIcon1;

# ----------------------------------------------------------------------- 
# Token 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS Token;

# ----------------------------------------------------------------------- 
# ServerFeature 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS ServerFeature;

# ----------------------------------------------------------------------- 
# Param 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS Param;

# ----------------------------------------------------------------------- 
# Feature 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS Feature;

# ----------------------------------------------------------------------- 
# ApiKey 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS ApiKey;

# ----------------------------------------------------------------------- 
# Whitelist 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS Whitelist;

# ----------------------------------------------------------------------- 
# WidgetType 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS WidgetType;

# ----------------------------------------------------------------------- 
# WidgetService 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS WidgetService;

# ----------------------------------------------------------------------- 
# WidgetDefault 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS WidgetDefault;

# ----------------------------------------------------------------------- 
# SharedData 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS SharedData;

# ----------------------------------------------------------------------- 
# Preference 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS Preference;

# ----------------------------------------------------------------------- 
# Participant 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS Participant;

# ----------------------------------------------------------------------- 
# PreferenceDefault 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS PreferenceDefault;

# ----------------------------------------------------------------------- 
# WidgetInstance 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS WidgetInstance;

# ----------------------------------------------------------------------- 
# StartFile 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS StartFile;

# ----------------------------------------------------------------------- 
# Description 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS Description;

# ----------------------------------------------------------------------- 
# AccessRequest 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS AccessRequest;

# ----------------------------------------------------------------------- 
# Name 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS Name;

# ----------------------------------------------------------------------- 
# License 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS License;

# ----------------------------------------------------------------------- 
# WidgetIcon 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS WidgetIcon;

# ----------------------------------------------------------------------- 
# Widget 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS Widget;

# ----------------------------------------------------------------------- 
# OPENJPA_SEQUENCE_TABLE 
# ----------------------------------------------------------------------- 

DROP TABLE IF EXISTS OPENJPA_SEQUENCE_TABLE;

# ----------------------------------------------------------------------- 
# OPENJPA_SEQUENCE_TABLE 
# ----------------------------------------------------------------------- 

CREATE TABLE OPENJPA_SEQUENCE_TABLE
(
    ID SMALLINT NOT NULL,
    SEQUENCE_VALUE BIGINT,
    PRIMARY KEY (ID)
) ;

# ----------------------------------------------------------------------- 
# Widget 
# ----------------------------------------------------------------------- 

CREATE TABLE Widget
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    height INTEGER,
    width INTEGER,
    guid VARCHAR(255) NOT NULL,
    widget_author VARCHAR(255) NULL,
    widget_author_email VARCHAR(320) NULL,
    widget_author_href MEDIUMTEXT NULL,
    widget_version VARCHAR(255) NULL,
    PRIMARY KEY (id)
) ;

CREATE UNIQUE INDEX UNWidget1 ON Widget (guid);

# ----------------------------------------------------------------------- 
# WidgetIcon 
# ----------------------------------------------------------------------- 

CREATE TABLE WidgetIcon
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    src MEDIUMTEXT NULL,
    height INTEGER,
    width INTEGER,
    lang VARCHAR(255) NULL,
    widget_id INTEGER,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXWidgetIcon1 ON WidgetIcon (widget_id);

# ----------------------------------------------------------------------- 
# License 
# ----------------------------------------------------------------------- 

CREATE TABLE License
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    href MEDIUMTEXT NULL,
    text MEDIUMTEXT NULL,
    dir VARCHAR(255) NULL,
    lang VARCHAR(255) NULL,
    widget_id INTEGER,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXLicense1 ON License (widget_id);

# ----------------------------------------------------------------------- 
# Name 
# ----------------------------------------------------------------------- 

CREATE TABLE Name
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    name MEDIUMTEXT NULL,
    shortName VARCHAR(255) NULL,
    dir VARCHAR(255) NULL,
    lang VARCHAR(255) NULL,
    widget_id INTEGER,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXName1 ON Name (widget_id);

# ----------------------------------------------------------------------- 
# AccessRequest 
# ----------------------------------------------------------------------- 

CREATE TABLE AccessRequest
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    origin VARCHAR(2048) NULL,
    subdomains CHAR(1) NULL,
    granted CHAR(1) NULL,
    widget_id INTEGER NOT NULL,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXAccessRequest1 ON AccessRequest (widget_id);

# ----------------------------------------------------------------------- 
# Description 
# ----------------------------------------------------------------------- 

CREATE TABLE Description
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    content MEDIUMTEXT NULL,
    dir VARCHAR(255) NULL,
    lang VARCHAR(255) NULL,
    widget_id INTEGER,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXDescription1 ON Description (widget_id);

# ----------------------------------------------------------------------- 
# StartFile 
# ----------------------------------------------------------------------- 

CREATE TABLE StartFile
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    url MEDIUMTEXT NULL,
    charset VARCHAR(255) NULL,
    lang VARCHAR(255) NULL,
    widget_id INTEGER,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXStartFile1 ON StartFile (widget_id);

# ----------------------------------------------------------------------- 
# WidgetInstance 
# ----------------------------------------------------------------------- 

CREATE TABLE WidgetInstance
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    apikey VARCHAR(255) NOT NULL,
    userId VARCHAR(255) NOT NULL,
    sharedDataKey VARCHAR(255) NULL,
    nonce VARCHAR(255) NULL,
    idKey VARCHAR(255) NOT NULL,
    opensocialToken MEDIUMTEXT NOT NULL,
    widget_id INTEGER NOT NULL,
    updated CHAR(1) NULL,
    shown CHAR(1) NULL,
    hidden CHAR(1) NULL,
    locked CHAR(1) NULL,
    lang VARCHAR(255) NULL,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXWidgetInstance1 ON WidgetInstance (widget_id);

CREATE UNIQUE INDEX UNWidgetInstance1 ON WidgetInstance (idKey);

# ----------------------------------------------------------------------- 
# PreferenceDefault 
# ----------------------------------------------------------------------- 

CREATE TABLE PreferenceDefault
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    widget_id INTEGER,
    preference VARCHAR(255) NOT NULL,
    value VARCHAR(1024) NOT NULL,
    readOnly CHAR(1) NULL,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXPreferenceDefault1 ON PreferenceDefault (widget_id);

# ----------------------------------------------------------------------- 
# Participant 
# ----------------------------------------------------------------------- 

CREATE TABLE Participant
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    participant_id VARCHAR(255) NOT NULL,
    participant_display_name VARCHAR(255) NOT NULL,
    participant_thumbnail_url VARCHAR(1024) NULL,
    sharedDataKey VARCHAR(255) NOT NULL,
    widget_id INTEGER NOT NULL,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXParticipant1 ON Participant (widget_id);

# ----------------------------------------------------------------------- 
# Preference 
# ----------------------------------------------------------------------- 

CREATE TABLE Preference
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    widget_instance_id INTEGER,
    dkey VARCHAR(255) NULL,
    dvalue MEDIUMTEXT NULL,
    readOnly CHAR(1) NULL,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXPreference1 ON Preference (widget_instance_id);

CREATE UNIQUE INDEX UNPreference1 ON Preference (widget_instance_id, dkey);

# ----------------------------------------------------------------------- 
# SharedData 
# ----------------------------------------------------------------------- 

CREATE TABLE SharedData
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    sharedDataKey VARCHAR(255) NULL,
    dkey VARCHAR(255) NULL,
    dvalue MEDIUMTEXT NULL,
    widget_id INTEGER,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXSharedData1 ON SharedData (widget_id);

# ----------------------------------------------------------------------- 
# WidgetDefault 
# ----------------------------------------------------------------------- 

CREATE TABLE WidgetDefault
(
    widgetContext VARCHAR(255) NOT NULL,
    jpa_version INTEGER,
    widgetId INTEGER NOT NULL,
    PRIMARY KEY (widgetContext)
) ;

CREATE INDEX IXWidgetDefault1 ON WidgetDefault (widgetId);

# ----------------------------------------------------------------------- 
# WidgetService 
# ----------------------------------------------------------------------- 

CREATE TABLE WidgetService
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    service_name VARCHAR(255) NOT NULL,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXWidgetService1 ON WidgetService (service_name);

# ----------------------------------------------------------------------- 
# WidgetType 
# ----------------------------------------------------------------------- 

CREATE TABLE WidgetType
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    widget_context VARCHAR(255) NULL,
    widget_id INTEGER,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXWidgetType1 ON WidgetType (widget_id);

# ----------------------------------------------------------------------- 
# Whitelist 
# ----------------------------------------------------------------------- 

CREATE TABLE Whitelist
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    fUrl VARCHAR(200) NOT NULL,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXWhitelist1 ON Whitelist (fUrl);

# ----------------------------------------------------------------------- 
# ApiKey 
# ----------------------------------------------------------------------- 

CREATE TABLE ApiKey
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    value VARCHAR(255) NOT NULL,
    email VARCHAR(255) NOT NULL,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXApiKey1 ON ApiKey (value);

# ----------------------------------------------------------------------- 
# Feature 
# ----------------------------------------------------------------------- 

CREATE TABLE Feature
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    featureName VARCHAR(255) NOT NULL,
    required CHAR(1) NULL,
    widget_id INTEGER,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXFeature1 ON Feature (widget_id);

# ----------------------------------------------------------------------- 
# Param 
# ----------------------------------------------------------------------- 

CREATE TABLE Param
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    feature_id INTEGER,
    parameterName VARCHAR(255) NOT NULL,
    parameterValue VARCHAR(255) NOT NULL,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXParam1 ON Param (feature_id);

# ----------------------------------------------------------------------- 
# ServerFeature 
# ----------------------------------------------------------------------- 

CREATE TABLE ServerFeature
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    featureName VARCHAR(255) NOT NULL,
    className VARCHAR(255) NOT NULL,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXServerFeature1 ON ServerFeature (featureName);

# ----------------------------------------------------------------------- 
# Token 
# ----------------------------------------------------------------------- 

CREATE TABLE Token
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    requestUrl VARCHAR(255) NOT NULL,
    accessUrl VARCHAR(255) NOT NULL,
    authzUrl VARCHAR(255) NOT NULL,
    requestToken VARCHAR(255) NOT NULL,
    accessToken VARCHAR(255) NOT NULL,
    tokenSecret VARCHAR(255) NOT NULL,
    widget_instance_id INTEGER,
    PRIMARY KEY (id)
) ;

CREATE INDEX IXToken1 ON Token (widget_instance_id);

ALTER TABLE WidgetIcon
    ADD CONSTRAINT FKWidgetIcon1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE License
    ADD CONSTRAINT FKLicense1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Name
    ADD CONSTRAINT FKName1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE AccessRequest
    ADD CONSTRAINT FKAccessRequest1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Description
    ADD CONSTRAINT FKDescription1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE StartFile
    ADD CONSTRAINT FKStartFile1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE WidgetInstance
    ADD CONSTRAINT FKWidgetInstance1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE PreferenceDefault
    ADD CONSTRAINT FKPreferenceDefault1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Participant
    ADD CONSTRAINT FKParticipant1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Preference
    ADD CONSTRAINT FKPreference1 FOREIGN KEY (widget_instance_id) REFERENCES WidgetInstance (id);

ALTER TABLE SharedData
    ADD CONSTRAINT FKSharedData1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE WidgetDefault
    ADD CONSTRAINT FKWidgetDefault1 FOREIGN KEY (widgetId) REFERENCES Widget (id);

ALTER TABLE WidgetType
    ADD CONSTRAINT FKWidgetType1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Feature
    ADD CONSTRAINT FKFeature1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Param
    ADD CONSTRAINT FKParam1 FOREIGN KEY (feature_id) REFERENCES Feature (id);

ALTER TABLE Token
    ADD CONSTRAINT FKToken1 FOREIGN KEY (widget_instance_id) REFERENCES WidgetInstance (id);

