-- ----------------------------------------------------------------------- 
-- Token 
-- ----------------------------------------------------------------------- 

DROP TABLE Token CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- ServerFeature 
-- ----------------------------------------------------------------------- 

DROP TABLE ServerFeature CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- Param 
-- ----------------------------------------------------------------------- 

DROP TABLE Param CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- Feature 
-- ----------------------------------------------------------------------- 

DROP TABLE Feature CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- ApiKey 
-- ----------------------------------------------------------------------- 

DROP TABLE ApiKey CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- Whitelist 
-- ----------------------------------------------------------------------- 

DROP TABLE Whitelist CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- WidgetType 
-- ----------------------------------------------------------------------- 

DROP TABLE WidgetType CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- WidgetService 
-- ----------------------------------------------------------------------- 

DROP TABLE WidgetService CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- WidgetDefault 
-- ----------------------------------------------------------------------- 

DROP TABLE WidgetDefault CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- SharedData 
-- ----------------------------------------------------------------------- 

DROP TABLE SharedData CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- Preference 
-- ----------------------------------------------------------------------- 

DROP TABLE Preference CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- Participant 
-- ----------------------------------------------------------------------- 

DROP TABLE Participant CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- PreferenceDefault 
-- ----------------------------------------------------------------------- 

DROP TABLE PreferenceDefault CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- WidgetInstance 
-- ----------------------------------------------------------------------- 

DROP TABLE WidgetInstance CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- StartFile 
-- ----------------------------------------------------------------------- 

DROP TABLE StartFile CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- Description 
-- ----------------------------------------------------------------------- 

DROP TABLE Description CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- AccessRequest 
-- ----------------------------------------------------------------------- 

DROP TABLE AccessRequest CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- Name 
-- ----------------------------------------------------------------------- 

DROP TABLE Name CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- License 
-- ----------------------------------------------------------------------- 

DROP TABLE License CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- WidgetIcon 
-- ----------------------------------------------------------------------- 

DROP TABLE WidgetIcon CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- Widget 
-- ----------------------------------------------------------------------- 

DROP TABLE Widget CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- OPENJPA_SEQUENCE_TABLE 
-- ----------------------------------------------------------------------- 

DROP TABLE OPENJPA_SEQUENCE_TABLE CASCADE CONSTRAINTS PURGE;

-- ----------------------------------------------------------------------- 
-- OPENJPA_SEQUENCE_TABLE 
-- ----------------------------------------------------------------------- 

CREATE TABLE OPENJPA_SEQUENCE_TABLE
(
    ID NUMBER(3) NOT NULL,
    SEQUENCE_VALUE NUMBER(38),
    PRIMARY KEY (ID)
);

-- ----------------------------------------------------------------------- 
-- Widget 
-- ----------------------------------------------------------------------- 

CREATE TABLE Widget
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    height INTEGER,
    width INTEGER,
    guid VARCHAR2(255) NOT NULL,
    widget_author VARCHAR2(255),
    widget_author_email VARCHAR2(320),
    widget_author_href CLOB,
    widget_version VARCHAR2(255),
    PRIMARY KEY (id)
);

CREATE UNIQUE INDEX UNWidget1 ON Widget (guid);

-- ----------------------------------------------------------------------- 
-- WidgetIcon 
-- ----------------------------------------------------------------------- 

CREATE TABLE WidgetIcon
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    src CLOB,
    height INTEGER,
    width INTEGER,
    lang VARCHAR2(255),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXWidgetIcon1 ON WidgetIcon (widget_id);

-- ----------------------------------------------------------------------- 
-- License 
-- ----------------------------------------------------------------------- 

CREATE TABLE License
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    href CLOB,
    text CLOB,
    dir VARCHAR2(255),
    lang VARCHAR2(255),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXLicense1 ON License (widget_id);

-- ----------------------------------------------------------------------- 
-- Name 
-- ----------------------------------------------------------------------- 

CREATE TABLE Name
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    name CLOB,
    shortName VARCHAR2(255),
    dir VARCHAR2(255),
    lang VARCHAR2(255),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXName1 ON Name (widget_id);

-- ----------------------------------------------------------------------- 
-- AccessRequest 
-- ----------------------------------------------------------------------- 

CREATE TABLE AccessRequest
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    origin VARCHAR2(2048),
    subdomains CHAR(1),
    granted CHAR(1),
    widget_id INTEGER NOT NULL,
    PRIMARY KEY (id)
);

CREATE INDEX IXAccessRequest1 ON AccessRequest (widget_id);

-- ----------------------------------------------------------------------- 
-- Description 
-- ----------------------------------------------------------------------- 

CREATE TABLE Description
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    content CLOB,
    dir VARCHAR2(255),
    lang VARCHAR2(255),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXDescription1 ON Description (widget_id);

-- ----------------------------------------------------------------------- 
-- StartFile 
-- ----------------------------------------------------------------------- 

CREATE TABLE StartFile
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    url CLOB,
    charset VARCHAR2(255),
    lang VARCHAR2(255),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXStartFile1 ON StartFile (widget_id);

-- ----------------------------------------------------------------------- 
-- WidgetInstance 
-- ----------------------------------------------------------------------- 

CREATE TABLE WidgetInstance
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    apikey VARCHAR2(255) NOT NULL,
    userId VARCHAR2(255) NOT NULL,
    sharedDataKey VARCHAR2(255),
    nonce VARCHAR2(255),
    idKey VARCHAR2(255) NOT NULL,
    opensocialToken CLOB NOT NULL,
    widget_id INTEGER NOT NULL,
    updated CHAR(1),
    shown CHAR(1),
    hidden CHAR(1),
    locked CHAR(1),
    lang VARCHAR2(255),
    PRIMARY KEY (id)
);

CREATE INDEX IXWidgetInstance1 ON WidgetInstance (widget_id);

CREATE UNIQUE INDEX UNWidgetInstance1 ON WidgetInstance (idKey);

-- ----------------------------------------------------------------------- 
-- PreferenceDefault 
-- ----------------------------------------------------------------------- 

CREATE TABLE PreferenceDefault
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    widget_id INTEGER,
    preference VARCHAR2(255) NOT NULL,
    value VARCHAR2(1024) NOT NULL,
    readOnly CHAR(1),
    PRIMARY KEY (id)
);

CREATE INDEX IXPreferenceDefault1 ON PreferenceDefault (widget_id);

-- ----------------------------------------------------------------------- 
-- Participant 
-- ----------------------------------------------------------------------- 

CREATE TABLE Participant
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    participant_id VARCHAR2(255) NOT NULL,
    participant_display_name VARCHAR2(255) NOT NULL,
    participant_thumbnail_url VARCHAR2(1024),
    sharedDataKey VARCHAR2(255) NOT NULL,
    widget_id INTEGER NOT NULL,
    PRIMARY KEY (id)
);

CREATE INDEX IXParticipant1 ON Participant (widget_id);

-- ----------------------------------------------------------------------- 
-- Preference 
-- ----------------------------------------------------------------------- 

CREATE TABLE Preference
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    widget_instance_id INTEGER,
    dkey VARCHAR2(255),
    dvalue CLOB,
    readOnly CHAR(1),
    PRIMARY KEY (id)
);

CREATE INDEX IXPreference1 ON Preference (widget_instance_id);

CREATE UNIQUE INDEX UNPreference1 ON Preference (widget_instance_id, dkey);

-- ----------------------------------------------------------------------- 
-- SharedData 
-- ----------------------------------------------------------------------- 

CREATE TABLE SharedData
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    sharedDataKey VARCHAR2(255),
    dkey VARCHAR2(255),
    dvalue CLOB,
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXSharedData1 ON SharedData (widget_id);

-- ----------------------------------------------------------------------- 
-- WidgetDefault 
-- ----------------------------------------------------------------------- 

CREATE TABLE WidgetDefault
(
    widgetContext VARCHAR2(255) NOT NULL,
    jpa_version INTEGER,
    widgetId INTEGER NOT NULL,
    PRIMARY KEY (widgetContext)
);

CREATE INDEX IXWidgetDefault1 ON WidgetDefault (widgetId);

-- ----------------------------------------------------------------------- 
-- WidgetService 
-- ----------------------------------------------------------------------- 

CREATE TABLE WidgetService
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    service_name VARCHAR2(255) NOT NULL,
    PRIMARY KEY (id)
);

CREATE INDEX IXWidgetService1 ON WidgetService (service_name);

-- ----------------------------------------------------------------------- 
-- WidgetType 
-- ----------------------------------------------------------------------- 

CREATE TABLE WidgetType
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    widget_context VARCHAR2(255),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXWidgetType1 ON WidgetType (widget_id);

-- ----------------------------------------------------------------------- 
-- Whitelist 
-- ----------------------------------------------------------------------- 

CREATE TABLE Whitelist
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    fUrl VARCHAR2(200) NOT NULL,
    PRIMARY KEY (id)
);

CREATE INDEX IXWhitelist1 ON Whitelist (fUrl);

-- ----------------------------------------------------------------------- 
-- ApiKey 
-- ----------------------------------------------------------------------- 

CREATE TABLE ApiKey
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    value VARCHAR2(255) NOT NULL,
    email VARCHAR2(255) NOT NULL,
    PRIMARY KEY (id)
);

CREATE INDEX IXApiKey1 ON ApiKey (value);

-- ----------------------------------------------------------------------- 
-- Feature 
-- ----------------------------------------------------------------------- 

CREATE TABLE Feature
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    featureName VARCHAR2(255) NOT NULL,
    required CHAR(1),
    widget_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXFeature1 ON Feature (widget_id);

-- ----------------------------------------------------------------------- 
-- Param 
-- ----------------------------------------------------------------------- 

CREATE TABLE Param
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    feature_id INTEGER,
    parameterName VARCHAR2(255) NOT NULL,
    parameterValue VARCHAR2(255) NOT NULL,
    PRIMARY KEY (id)
);

CREATE INDEX IXParam1 ON Param (feature_id);

-- ----------------------------------------------------------------------- 
-- ServerFeature 
-- ----------------------------------------------------------------------- 

CREATE TABLE ServerFeature
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    featureName VARCHAR2(255) NOT NULL,
    className VARCHAR2(255) NOT NULL,
    PRIMARY KEY (id)
);

CREATE INDEX IXServerFeature1 ON ServerFeature (featureName);

-- ----------------------------------------------------------------------- 
-- Token 
-- ----------------------------------------------------------------------- 

CREATE TABLE Token
(
    id INTEGER NOT NULL,
    jpa_version INTEGER,
    requestUrl VARCHAR2(255) NOT NULL,
    accessUrl VARCHAR2(255) NOT NULL,
    authzUrl VARCHAR2(255) NOT NULL,
    requestToken VARCHAR2(255) NOT NULL,
    accessToken VARCHAR2(255) NOT NULL,
    tokenSecret VARCHAR2(255) NOT NULL,
    widget_instance_id INTEGER,
    PRIMARY KEY (id)
);

CREATE INDEX IXToken1 ON Token (widget_instance_id);

ALTER TABLE WidgetIcon
    ADD CONSTRAINT FKWidgetIcon1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE License
    ADD CONSTRAINT FKLicense1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Name
    ADD CONSTRAINT FKName1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE AccessRequest
    ADD CONSTRAINT FKAccessRequest1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Description
    ADD CONSTRAINT FKDescription1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE StartFile
    ADD CONSTRAINT FKStartFile1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE WidgetInstance
    ADD CONSTRAINT FKWidgetInstance1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE PreferenceDefault
    ADD CONSTRAINT FKPreferenceDefault1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Participant
    ADD CONSTRAINT FKParticipant1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Preference
    ADD CONSTRAINT FKPreference1 FOREIGN KEY (widget_instance_id) REFERENCES WidgetInstance (id);

ALTER TABLE SharedData
    ADD CONSTRAINT FKSharedData1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE WidgetDefault
    ADD CONSTRAINT FKWidgetDefault1 FOREIGN KEY (widgetId) REFERENCES Widget (id);

ALTER TABLE WidgetType
    ADD CONSTRAINT FKWidgetType1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Feature
    ADD CONSTRAINT FKFeature1 FOREIGN KEY (widget_id) REFERENCES Widget (id);

ALTER TABLE Param
    ADD CONSTRAINT FKParam1 FOREIGN KEY (feature_id) REFERENCES Feature (id);

ALTER TABLE Token
    ADD CONSTRAINT FKToken1 FOREIGN KEY (widget_instance_id) REFERENCES WidgetInstance (id);

